import QtQuick 2.6
import Sailfish.Silica 1.0
import Simple.Hybrid 1.0

Page {
    TextProcessor {
        id: textProcessor
        action: actionSelector.action
        onTextChanged: if (textField.text !== text) textField.text = text
    }
    SilicaFlickable {
        anchors.fill: parent
        contentHeight: contentColumn.height

        Column {
            id: contentColumn
            width: parent.width
            spacing: Theme.paddingLarge

            PageHeader { title: qsTr("Text Processor") }
            TextField {
                id: textField
                width: parent.width
                placeholderText: qsTr("Input text to process")
                label: qsTr("Text to process")
                onTextChanged: if (textProcessor.text !== text) textProcessor.text = text
            }
            ComboBox {
                id: actionSelector

                readonly property int action: [
                    TextProcessor.NoAction,
                    TextProcessor.MakeUppercase,
                    TextProcessor.MakeLowercase
                ][currentIndex]

                width: parent.width
                label: qsTr("Action")
                menu: ContextMenu {
                    MenuItem { text: qsTr("No action") }
                    MenuItem { text: qsTr("Make uppercase") }
                    MenuItem { text: qsTr("Make lowercase") }
                }
            }
            TextField {
                width: parent.width
                label: qsTr("Processed text")
                placeholderText: label
                text: textProcessor.processedText
                readOnly: true
                color: Theme.highlightColor
                placeholderColor: color
            }
            Item { width: parent.width; height: Theme.paddingLarge }
            TextField {
                id: prependTextField
                width: parent.width
                placeholderText: qsTr("Input text to prepend")
                label: qsTr("Text to prepend")
            }
            Button {
                text: qsTr("Prepend")
                anchors.horizontalCenter: parent.horizontalCenter
                width: Theme.buttonWidthLarge
                onClicked: textProcessor.prepend(prependTextField.text)
            }
        }
    }
}
