#ifndef STRINGPROCESSOR_H
#define STRINGPROCESSOR_H

#include <QObject>

class TextProcessor : public QObject
{
    Q_OBJECT
    Q_PROPERTY(QString text READ text WRITE setText NOTIFY textChanged)
    Q_PROPERTY(Action action READ action WRITE setAction NOTIFY actionChanged)
    Q_PROPERTY(QString processedText READ processedText NOTIFY processedTextChanged)

public:
    enum Action { NoAction, MakeUppercase, MakeLowercase };
    Q_ENUM(Action)

    explicit TextProcessor(QObject *parent = nullptr);
    QString text() const;
    Action action() const;
    QString processedText() const;

    Q_INVOKABLE QString prepend(const QString &string);

signals:
    void textChanged();
    void actionChanged();
    void processedTextChanged();

public slots:
    void setText(const QString &text);
    void setAction(Action action);

private:
    QString _text;
    Action _action;
};

#endif // STRINGPROCESSOR_H
